@@ -1,6 +1,6 @@
 ### ctrdata package
 
-#' Merge variables, keeping type, and optionally relevel factors
+#' Merge variables, keeping type where possible, optionally relevel factors
 #'
 #' Merge variables in a data frame such as returned by \link{dbGetFieldsIntoDf}
 #' into a new variable, and optionally also map its values to new levels.
@@ -20,6 +20,7 @@
 #' @return A vector, with the type of the columns to be merged
 #'
 #' @importFrom dplyr select
+#' @importFrom tidyr unite
 #'
 #' @export
 #'
@@ -53,10 +54,6 @@ dfMergeVariablesRelevel <- function(
   stopifnot(is.data.frame(df))
   stopifnot(is.character(colnames))
 
-  # initialise
-  env <- new.env()
-  evalq(warned <- FALSE, env)
-
   # identify columns
   if (length(colnames) == 1L && grepl("[()]", colnames)) {
 
@@ -73,26 +70,28 @@ dfMergeVariablesRelevel <- function(
   stopifnot(all(colnames %in% names(df)))
   if (length(colnames) == 1L) return(df[[colnames]])
 
-  # mapply helper
-  merge2Cols <- function(x, y) {
-    mapply(function(x, y) {
-      x <- x[x != ""]; y <- y[y != ""]
-      if (!length(x) && !length(y)) return(NA)
-      if (length(x) && !is.na(x) && length(y) && !is.na(y)) {
-        if (!get("warned", envir = env)) {message(
-          "More than one column had values, returning e.g. '", x, " / ", y, "'")
-          evalq(warned <- TRUE, env)}
-        return(paste(c(x, y), collapse = " / "))}
-      if (!is.na(x)) return(x) else return(y)},
-      x, y, USE.NAMES = FALSE)
-  }
+  # check
+  if(all(apply(df[, colnames, drop = FALSE], 1,
+           function(r) length(na.omit(r))) <= 1L)) {
 
-  # merge
-  out <- Reduce(
-    f = merge2Cols,
-    x = as.list(df[, colnames[-1], drop = FALSE]),
-    init = df[, colnames[1], drop = TRUE]
-  )
+    out <- do.call(
+      dplyr::coalesce, as.list(df[, colnames, drop = FALSE]))
+
+  } else {
+
+    out <- tidyr::unite(
+      df[, colnames, drop = FALSE],
+      out, na.rm = TRUE, sep = " / "
+    )[["out"]]
+
+    out <- trimws(gsub(" / ($)|(^) / |( / ) */ ", "\\1", out))
+
+    message(
+      "More than one column had values, returning e.g. '",
+      out[grepl(" / ", out)][1], "'"
+    )
+
+  }
 
   # label levels
   if (!is.null(levelslist)) {
